import java.awt.*;
import java.awt.color.ColorSpace;
import java.awt.event.*; 
import net.java.games.jogl.*;

public class JOGL2DBasics extends Frame implements GLEventListener {
    
    public static final Dimension PREFERRED_FRAME_SIZE =new Dimension (450,375);
    
    public JOGL2DBasics() {
        super ("Primitivas 2D con JOGL (OpenGL para Java)");
        GLCapabilities capabilities = new GLCapabilities();
        GLCanvas canvas = GLDrawableFactory.getFactory().createGLCanvas(capabilities);
        canvas.addGLEventListener(this);
        add (canvas, BorderLayout.CENTER);
    }

    public Dimension getPreferredSize () {
        return PREFERRED_FRAME_SIZE;
    }
    
    public static void main (String[] args) {
        Frame f = new JOGL2DBasics();
        f.pack();
        f.setVisible(true);
    }
    
    public void display (GLDrawable drawable) {
        long inTime = System.currentTimeMillis();
        GL gl = drawable.getGL();
        GLU glu = drawable.getGLU();
        gl.glClear (GL.GL_COLOR_BUFFER_BIT);
        drawSomeDots(gl);
        drawSomeLines(gl);
        drawOpenPoly(gl);
        drawClosedPoly(gl);
        drawFilledRect (gl, Color.cyan.darker());
        drawFilledPoly (gl, Color.red.darker());
        drawTriangles (gl);
    }
    
    public void displayChanged(GLDrawable drawable,boolean modeChanged,boolean deviceChanged) {}
    
    public void init (GLDrawable drawable) {      
        GL gl = drawable.getGL(); 
        gl.glClearColor( 1.0f, 1.0f, 1.0f, 0.0f ); 
        gl.glColor3f( 0.0f, 0.0f, 0.0f ); 
        gl.glPointSize(4.0f); 
    }
    
    public void reshape (GLDrawable drawable,int x,int y,int width,int height) {
        GL gl = drawable.getGL(); 
        GLU glu = drawable.getGLU(); 
        gl.glViewport( 0, 0, width, height ); 
        gl.glMatrixMode( GL.GL_PROJECTION );  
        gl.glLoadIdentity(); 
        glu.gluOrtho2D( 0.0, 450.0, 0.0, 375.0); 
    }

    protected void drawSomeDots(GL gl) {
        gl.glBegin (GL.GL_POINTS);
        gl.glVertex2i (100,50);
        gl.glVertex2i (100,130);
        gl.glVertex2i (150,130);
        gl.glEnd ();
    }
    
    protected void drawSomeLines (GL gl) {
        gl.glBegin (GL.GL_LINES);
        gl.glVertex2i (50, 200);
        gl.glVertex2i (75, 250);
        gl.glVertex2i (60, 200);
        gl.glVertex2i (85, 250);
        gl.glEnd();
    }
    
    protected void drawOpenPoly (GL gl) {
        gl.glBegin (GL.GL_LINE_STRIP);
        gl.glVertex2i (100, 200);
        gl.glVertex2i (150, 250);
        gl.glVertex2i (100, 250);
        gl.glVertex2i (150, 200);
        gl.glEnd();    
    }
    
    protected void drawClosedPoly (GL gl) {
        gl.glBegin (GL.GL_LINE_LOOP);
        gl.glVertex2i (200, 200);
        gl.glVertex2i (250, 250);
        gl.glVertex2i (200, 250);
        gl.glVertex2i (250, 200);
        gl.glEnd();    
    }
    
    protected void drawTriangles (GL gl) {
        gl.glBegin (GL.GL_TRIANGLES);
        gl.glVertex2i (400, 50);
        gl.glVertex2i (400, 100);
        gl.glVertex2i (420, 75);
        gl.glVertex2i (425, 50);
        gl.glVertex2i (425, 100);
        gl.glVertex2i (445, 75);
        gl.glEnd();    
    }
    
    protected void drawFilledRect (GL gl, Color c) {
        float redF = c.getRed() / 255f;
        float greenF = c.getGreen() / 255f;
        float blueF = c.getBlue() / 255f;
        gl.glColor3f (redF, greenF, blueF);
        gl.glRecti (200, 50, 250, 150);
        gl.glColor3f (0.0f, 0.0f, 0.0f);
    }
    
    protected void drawFilledPoly (GL gl, Color c) {
        float redF = c.getRed() / 255f;
        float greenF = c.getGreen() / 255f;
        float blueF = c.getBlue() / 255f;
        gl.glColor3f (redF, greenF, blueF);
        gl.glBegin (GL.GL_POLYGON);
        gl.glVertex2i (300, 50);
        gl.glVertex2i (350, 60);
        gl.glVertex2i (375, 100);
        gl.glVertex2i (325, 115);
        gl.glVertex2i (300, 75);
        gl.glEnd();    
        // now reset the color to black
        gl.glColor3f (0.0f, 0.0f, 0.0f);
    }
        
}
